@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '2.060007';
+our $VERSION = '2.060008';
 use App::Netdisco::Configuration;
 
 =head1 NAME
@@ -94,7 +94,9 @@ On FreeBSD systems please see L<our FreeBSD tips|https://github.com/netdisco/net
 
 On OpenBSD systems please see L<our OpenBSD tips|https://github.com/netdisco/netdisco/wiki/openbsd-install>.
 
-With those installed, please check that your system's clock is correct.
+With those installed, please check that your system's clock is correct. We
+also recommend that you run Netdisco in UTC (time zone +0) if possible, to
+avoid issues with Daylight Savings Time changes.
 
 Create a user on your system called C<netdisco> if one does not already exist.
 We'll install Netdisco and its dependencies into this user's home area, which
@@ -354,7 +356,7 @@ built upon.
 
 =head1 COPYRIGHT AND LICENSE
  
-This software is copyright (c) 2011-2019 by The Netdisco Developer Team.
+This software is copyright (c) 2011-2023 by The Netdisco Developer Team.
  
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
